@@ -15,7 +15,7 @@ except ImportError:
 
 from groclient import cfg, lib
 from groclient.constants import DATA_SERIES_UNIQUE_TYPES_ID, ENTITY_KEY_TO_TYPE
-from groclient.utils import intersect, zip_selections, dict_unnest
+from groclient.utils import intersect, zip_selections, dict_unnest, str_snake_to_camel
 from groclient.lib import APIError
 
 import pandas
@@ -313,6 +313,13 @@ class GroClient(object):
         headers = {"authorization": "Bearer " + self.access_token}
         url = "/".join(["https:", "", self.api_host, "v2/data"])
         params = lib.get_data_call_params(**selection)
+        required_params = [str_snake_to_camel(type_id) for type_id in DATA_SERIES_UNIQUE_TYPES_ID if type_id != 'partner_region_id']
+        missing_params = list(required_params - params.keys())
+        if len(missing_params):
+            message = 'API request cannot be processed because {} not specified.'.format(missing_params[0] + ' is' if len(missing_params) == 1 else ', '.join(missing_params[:-1]) + ' and ' + missing_params[-1] + ' are')
+            self._logger.error(message)
+            raise ValueError(message)
+
         try:
             list_of_series_points = yield self.async_get_data(url, headers, params)
             include_historical = selection.get("include_historical", True)
@@ -579,6 +586,39 @@ class GroClient(object):
         """
         return lib.get_data_series(self.access_token, self.api_host, **selection)
 
+    def stream_data_series(self, chunk_size=10000, **selection):
+        """Retrieve available data series for the given selections.
+        Similar to :meth:`~.get_data_series`, but API will stream data in chunk of given size
+
+        Parameters
+        ----------
+        chunk_size : integer, optional
+            Number of data series to be returned in each chunk. Defaults to 10000
+        metric_id : integer, optional
+        item_id : integer, optional
+        region_id : integer, optional
+        partner_region_id : integer, optional
+        source_id : integer, optional
+        frequency_id : integer, optional
+
+        Yields
+        -------
+        list of dicts
+
+            Example::
+
+                [{ 'metric_id': 2020032, 'metric_name': 'Seed Use',
+                   'item_id': 274, 'item_name': 'Corn',
+                   'region_id': 1215, 'region_name': 'United States',
+                   'source_id': 24, 'source_name': 'USDA FEEDGRAINS',
+                   'frequency_id': 7,
+                   'start_date': '1975-03-01T00:00:00.000Z',
+                   'end_date': '2018-05-31T00:00:00.000Z'
+                 }, { ... }, ... ]
+
+        """
+        return lib.stream_data_series(self.access_token, self.api_host, chunk_size, **selection)
+
     def search(self, entity_type, search_terms):
         """Search for the given search term. Better matches appear first.
 
@@ -1057,7 +1097,7 @@ class GroClient(object):
             reporting_history : boolean, optional
                 False by default. If true, will return all reporting history from the source.
             complete_history : boolean, optional
-                False by default. If true, will return complete history of data points for the selection. This will include 
+                False by default. If true, will return complete history of data points for the selection. This will include
                 the reporting history from the source and revisions Gro has captured that may not have been released with an official reporting_date.
             index_by_series : boolean, optional
                If set, the dataframe is indexed by series. See https://developers.gro-intelligence.com/data-series-definition.html
@@ -1279,7 +1319,7 @@ class GroClient(object):
         reporting_history : boolean, optional
             False by default. If true, will return all reporting history from the source.
         complete_history : boolean, optional
-            False by default. If true, will return complete history of data points for the selection. This will include 
+            False by default. If true, will return complete history of data points for the selection. This will include
             the reporting history from the source and revisions Gro has captured that may not have been released with an official reporting_date.
         insert_null : boolean, optional
             False by default. If True, will include a data point with a None value for each period
