@@ -160,7 +160,7 @@ def convert_value(value, from_convert_factor, to_convert_factor):
     ) / to_convert_factor.get("factor")
 
 
-def get_data(url, headers, params=None, logger=None):
+def get_data(url, headers, params=None, logger=None, stream=False):
     """General 'make api request' function.
 
     Assigns headers and builds in retries and logging.
@@ -179,10 +179,8 @@ def get_data(url, headers, params=None, logger=None):
     """
     base_log_record = dict(route=url, params=params)
     retry_count = 0
-
     # append version info
     headers.update(get_version_info())
-
     if not logger:
         logger = get_default_logger()
         logger.debug(url)
@@ -190,7 +188,7 @@ def get_data(url, headers, params=None, logger=None):
     while retry_count <= cfg.MAX_RETRIES:
         start_time = time.time()
         try:
-            response = requests.get(url, params=params, headers=headers, timeout=None)
+            response = requests.get(url, params=params, headers=headers, timeout=None, stream=stream)
         except Exception as e:
             response = e
         elapsed_time = time.time() - start_time
@@ -225,7 +223,6 @@ def get_data(url, headers, params=None, logger=None):
         retry_count += 1
     raise APIError(response, retry_count, url, params)
 
-
 @memoize(maxsize=None)
 def get_allowed_units(access_token, api_host, metric_id, item_id):
     url = '/'.join(['https:', '', api_host, 'v2/units/allowed'])
@@ -347,8 +344,8 @@ def get_data_call_params(**selection):
     frequency_id : integer
     start_date : string, optional
     end_date : string, optional
-    show_revisions : boolean, optional
-    show_available_date : boolean, optional
+    reporting_history : boolean, optional
+    complete_history : boolean, optional
     insert_null : boolean, optional
     show_metadata : boolean, optional
     at_time : string, optional,
@@ -364,7 +361,11 @@ def get_data_call_params(**selection):
     for key, value in list(selection.items()):
         if key == 'show_metadata':
             params[groclient.utils.str_snake_to_camel('show_meta_data')] = value
-        if key in ('start_date', 'end_date', 'show_revisions', 'show_available_date', 'insert_null', 'at_time', 'available_since'):
+        elif key == 'complete_history':
+            params['showHistory'] = value
+        elif key in ('show_revisions', 'reporting_history'):
+            params['showReportingDate'] = value
+        elif key in ('start_date', 'end_date', 'insert_null', 'at_time', 'available_since'):
             params[groclient.utils.str_snake_to_camel(key)] = value
     params['responseType'] = 'list_of_series'
     return params
@@ -386,6 +387,26 @@ def get_data_series(access_token, api_host, **selection):
     except KeyError:
         raise Exception(resp.text)
 
+def stream_data_series(access_token, api_host, chunk_size=None, **selection):
+    logger = get_default_logger()
+    url = '/'.join(['https:', '', api_host, 'v2/stream/data_series/list'])
+    headers = {'authorization': 'Bearer ' + access_token}
+    params = get_params_from_selection(**selection)
+    if type(chunk_size) == int and chunk_size>1:
+        params['chunkSize'] = chunk_size
+    resp = get_data(url, headers, params, logger, True)
+    try:
+        for line in resp.iter_lines(decode_unicode=True):
+            if line:
+                current_ds_list = json.loads(line)
+                if any((series.get('metadata', {}).get('includes_historical_region', False))
+                        for series in current_ds_list):
+                    logger.warning('Data series have some historical regions, '
+                                'see https://developers.gro-intelligence.com/faq.html')
+                yield current_ds_list
+    except KeyError:
+        raise Exception(resp.text)
+
 
 def get_top(access_token, api_host, entity_type, num_results=5, **selection):
     url = '/'.join(['https:', '', api_host, 'v2/top/{}'.format(entity_type)])
@@ -465,7 +486,7 @@ def get_available_timefrequency(access_token, api_host, **series):
             for tf in response.json()]
 
 
-def list_of_series_to_single_series(series_list, add_belongs_to=False, include_historical=True, include_available_date=False):
+def list_of_series_to_single_series(series_list, add_belongs_to=False, include_historical=True):
     """Convert list_of_series format from API back into the familiar single_series output format."""
     if not isinstance(series_list, list):
         # If the output is an error or None or something else that's not a list, just propagate
@@ -497,6 +518,8 @@ def list_of_series_to_single_series(series_list, add_belongs_to=False, include_h
                 'input_unit_scale': 1,
                 # If a point does not have reporting_date, use None
                 'reporting_date': point[3] if len(point) > 3 else None,
+                # If a point does not have available_date, use None
+                'available_date': point[6] if len(point) > 6 else None,
                 # Series attributes:
                 'metric_id': series['series'].get('metricId', None),
                 'item_id': series['series'].get('itemId', None),
@@ -505,9 +528,6 @@ def list_of_series_to_single_series(series_list, add_belongs_to=False, include_h
                 'frequency_id': series['series'].get('frequencyId', None)
                 # 'source_id': series['series'].get('sourceId', None), TODO: add source to output
             }
-            if include_available_date:
-                # If a point does not have available_date, use None
-                formatted_point['available_date'] = point[6] if len(point) > 6 else None
 
             if formatted_point['metadata'].get('confInterval') is not None:
                 formatted_point['metadata']['conf_interval'] = formatted_point['metadata'].pop('confInterval')
@@ -522,13 +542,19 @@ def list_of_series_to_single_series(series_list, add_belongs_to=False, include_h
 
 
 def get_data_points(access_token, api_host, **selection):
+    logger = get_default_logger()
     headers = {'authorization': 'Bearer ' + access_token}
     url = '/'.join(['https:', '', api_host, 'v2/data'])
     params = get_data_call_params(**selection)
+    required_params = [groclient.utils.str_snake_to_camel(type_id) for type_id in DATA_SERIES_UNIQUE_TYPES_ID if type_id != 'partner_region_id']
+    missing_params = list(required_params - params.keys())
+    if len(missing_params):
+        message = 'API request cannot be processed because {} not specified.'.format(missing_params[0] + ' is' if len(missing_params) == 1 else ', '.join(missing_params[:-1]) + ' and ' + missing_params[-1] + ' are')
+        logger.error(message)
+        raise ValueError(message)
     resp = get_data(url, headers, params)
     include_historical = selection.get('include_historical', True)
-    include_available_date = selection.get('show_available_date', False)
-    return list_of_series_to_single_series(resp.json(), False, include_historical, include_available_date)
+    return list_of_series_to_single_series(resp.json(), False, include_historical)
 
 
 @memoize(maxsize=None)
@@ -606,70 +632,65 @@ def get_geojson(access_token, api_host, region_id, zoom_level):
 
 
 def get_ancestor(access_token, api_host, entity_type, entity_id, distance=None,
-                   include_details=True):
+                 include_details=True, ancestor_level=None, include_historical=True,):
     url = '/'.join(['https:', '', api_host, 'v2/{}/belongs-to'.format(entity_type)])
     headers = {'authorization': 'Bearer ' + access_token}
     params = {'ids': [entity_id]}
     if distance:
         params['distance'] = distance
     else:
-        params['distance'] = -1
+        if entity_type == 'regions' and ancestor_level:
+            params['level'] = ancestor_level
+        else:
+            params['distance'] = -1
 
     resp = get_data(url, headers, params)
     ancestor_entity_ids = resp.json()['data'][str(entity_id)]
 
-    if include_details:
+    # Filter out regions with the 'historical' flag set to true
+    if not include_historical or include_details:
         entity_details = lookup(access_token, api_host, entity_type, ancestor_entity_ids)
-        return [entity_details[str(child_entity_id)] for child_entity_id in ancestor_entity_ids]
+
+        if not include_historical:
+            ancestor_entity_ids = [entity['id'] for entity in entity_details.values()
+                                     if not entity['historical']]
+
+        if include_details:
+            return [entity_details[str(child_entity_id)] for child_entity_id in
+                    ancestor_entity_ids]
 
     return [{'id': ancestor_entity_id} for ancestor_entity_id in ancestor_entity_ids]
 
 
 def get_descendant(access_token, api_host, entity_type, entity_id, distance=None,
-                   include_details=True):
+                   include_details=True, descendant_level=None, include_historical=True):
     url = '/'.join(['https:', '', api_host, 'v2/{}/contains'.format(entity_type)])
     headers = {'authorization': 'Bearer ' + access_token}
     params = {'ids': [entity_id]}
     if distance:
         params['distance'] = distance
     else:
-        params['distance'] = -1
+        if entity_type == 'regions' and descendant_level:
+            params['level'] = descendant_level
+        else:
+            params['distance'] = -1
 
     resp = get_data(url, headers, params)
     descendant_entity_ids = resp.json()['data'][str(entity_id)]
 
-    if include_details:
-        entity_details = lookup(access_token, api_host, entity_type, descendant_entity_ids)
-        return [entity_details[str(child_entity_id)] for child_entity_id in descendant_entity_ids]
-
-    return [{'id': descendant_entity_id} for descendant_entity_id in descendant_entity_ids]
-
-
-def get_descendant_regions(access_token, api_host, region_id,
-                           descendant_level=None, include_historical=True, include_details=True):
-    url = '/'.join(['https:', '', api_host, 'v2/regions/contains'])
-    headers = {'authorization': 'Bearer ' + access_token}
-    params = {'ids': [region_id]}
-    if descendant_level:
-        params['level'] = descendant_level
-    else:
-        params['distance'] = -1
-
-    resp = get_data(url, headers, params)
-    descendant_region_ids = resp.json()['data'][str(region_id)]
-
     # Filter out regions with the 'historical' flag set to true
     if not include_historical or include_details:
-        region_details = lookup(access_token, api_host, 'regions', descendant_region_ids)
+        entity_details = lookup(access_token, api_host, entity_type, descendant_entity_ids)
 
         if not include_historical:
-            descendant_region_ids = [region['id'] for region in region_details.values()
-                                     if not region['historical']]
+            descendant_entity_ids = [entity['id'] for entity in entity_details.values()
+                                     if not entity['historical']]
 
         if include_details:
-            return [region_details[str(region_id)] for region_id in descendant_region_ids]
+            return [entity_details[str(child_entity_id)] for child_entity_id in
+                    descendant_entity_ids]
 
-    return [{'id': descendant_region_id} for descendant_region_id in descendant_region_ids]
+    return [{'id': descendant_entity_id} for descendant_entity_id in descendant_entity_ids]
 
 
 if __name__ == '__main__':
